@@ -499,6 +499,69 @@ class TestResolverList(unittest.TestCase):
         {('/This/a7.ini', 'section8'): rl[1], ('/This/a7.ini', 'section7'): rl[0], ('/This/a7.ini', 'section9'): rl[2]}))
         self.assertEqual(rl[2].kw, {})
 
+    def test_resolverlist_works1(self):
+        rl = self.resolverlist('http://127.0.0.1:6543', JuicerConfigParser=MockConfigParser, Resolver=MockResolver)
+        rl.add_new_section('/This/a7.ini', 'section7', {})
+
+        # test if it actually works
+        # for this we bump the second and third mock resolvers to give a different result set
+        rl[1]._bump_mock_results(1)
+        rl[2]._bump_mock_results(2)
+
+        # now, the result of resolving
+        js = rl.resolve_js('http://127.0.0.1:6543/static/default.min.js')
+        self.assertEqual(js, [ 
+                             'http://127.0.0.1:6543/static/a.js', 
+                             'http://127.0.0.1:6543/static/b.js',
+                             'http://127.0.0.1:6543/static/default.js',
+                             ]
+                             )
+        css = rl.resolve_css('http://127.0.0.1:6543/static/default.min.css')
+        self.assertEqual(css, [ 
+                             'http://127.0.0.1:6543/static/default.css',
+                             ]
+                             )
+
+        js = rl.resolve_js('http://127.0.0.1:6543/static/default2.min.js')
+        self.assertEqual(js, [ 
+                             'http://127.0.0.1:6543/static/a2.js', 
+                             'http://127.0.0.1:6543/static/b2.js',
+                             'http://127.0.0.1:6543/static/default2.js',
+                             ]
+                             )
+        css = rl.resolve_css('http://127.0.0.1:6543/static/default2.min.css')
+        self.assertEqual(css, [ 
+                             'http://127.0.0.1:6543/static/default2.css',
+                             ]
+                             )
+
+        js = rl.resolve_js('http://127.0.0.1:6543/static/default3.min.js')
+        self.assertEqual(js, [ 
+                             'http://127.0.0.1:6543/static/a3.js', 
+                             'http://127.0.0.1:6543/static/b3.js',
+                             'http://127.0.0.1:6543/static/default3.js',
+                             ]
+                             )
+        css = rl.resolve_css('http://127.0.0.1:6543/static/default3.min.css')
+        self.assertEqual(css, [ 
+                             'http://127.0.0.1:6543/static/default3.css',
+                             ]
+                             )
+
+
+
+        js = rl.resolve_js('http://127.0.0.1:6543/static/defaultNOSUCH.min.js')
+        self.assertEqual(js, [ 
+                             'http://127.0.0.1:6543/static/defaultNOSUCH.min.js'
+                             ]
+                             )
+        css = rl.resolve_css('http://127.0.0.1:6543/static/defaultNOSUCH.min.css')
+        self.assertEqual(css, [ 
+                             'http://127.0.0.1:6543/static/defaultNOSUCH.min.css',
+                             ]
+                             )
+
+
     def test_extend2(self):
         rl = self.resolverlist('http://127.0.0.1:6543', JuicerConfigParser=MockConfigParser, Resolver=MockResolver)
         rl.add_new_section('/This/a10.ini', 'section10', {})
